% Script file listing all commands used to process Flowset fs10
% 
% To process another flowset, follow the instructions below (***) and modify individual
% commands and commands/parameters in the files "compile_variogram_example.m",
% "variogram_model_manualfit_example.m" and "krig_fs10_example.m".



% (i) DATA PREPARATION ----------------------------------------------------

% *** User prepares the matrix F and saves it in the file "flowset.mat" *** 
% Matrix F has the 5-column structure [Lineament_ID x_start y_start x_end y_end].

% create matrix F1 (from F) and save it to "flowset.mat"
make_flowdir_matrix;

% *** Alternatively, user prepares the matrix F1 directly and saves it in the file "flowset.mat" *** 
% *** (and skip the command on Line 15) ***



% (ii) VARIOGRAM COMPILATION ----------------------------------------------

% calculate experimental variogram data
compile_variogram_example;
% *** See Lines 5-6 and 9-10 in the file "compile_variogram_example.m". This example calculates 
% experimental variogram data at two resolutions: dh = 0.5, hmax = 10 and dh = 5, hmax = 100.
% Modify these lines to achieve other resolutions. ***

% manual-fitting of the model variogram of Equations (5) and (6) to the experimental variogram data
% and plot the results
variogram_model_manualfit_example;
% *** To achieve a different fit, or to fit the variogram model to the experimental variogram data 
% of another flowset, adjust the choices of C0, C1, C2, C3 and C4 on Line 20 of "variogram_model_manualfit_example.m"

pause
close all



% (iii) KRIGING INTERPOLATION ---------------------------------------------

% kriging with the kriging range R and across a rectangular domain at a certain spatial resolution, all specified by the user 
krig_fs10_example;
% *** In "krig_fs10_example.m":
%       - Specify the kriging range R on Line 11 (the example uses R = 50, chosen based on the approximate location 
%           of the "sill" of the experimental variogram in Figure 2c of the paper)
%       - Specify the rectangular domain on Line 14 (the example uses domain = [330 430 600 680],
%           i.e., x ranging from 330 to 430, and y ranging from 600 to 680.
%       - Specify the resolution (i.e. step size) in the x and y directions on Lines 15 and 16 
%           (the example uses dx = dy = 0.5).





% (iv) VALIDATION ---------------------------------------------------------
[residuals,residuals_mean,RMSE,CR] = krig_validation;
load results/kriging_results vg_params R
save results/validation_results vg_params R residuals residuals_mean RMSE CR
figure
plot(residuals,'+k'); xlabel('position ID'); ylabel('residual (deg.)'); axis([0 length(residuals) -50 50])
title(['C0 = ' num2str(vg_params(1)) '; C1 = ' num2str(vg_params(2)) '; C2 = ' num2str(vg_params(3)) ]); 
text(50,40,['mean of residuals = ' num2str(residuals_mean) '; RMSE = ' num2str(RMSE)])
print -dtiff results/validation_residuals
pause
clear
close all





