% Sample command lines used to (i) fit (manually) our variogram model to the experimental variogram 
% for flowset FS10 and (ii) plot the corresponding results


load results/experimental_variogram_data


% (1) plot experimental variogram at two scales
figure(1)
plot(hc1,gam1,'.r'); hold on; plot(hc2,gam2,'xb'); xlabel('h'); ylabel('gam');
axis([0 15 0 0.12])
%
figure(2)
plot(hc1,gam1,'.r'); hold on; plot(hc2,gam2,'xb'); xlabel('h'); ylabel('gam');
axis([0 80 0 0.8])


% (2) define model variogram
% CHOOSE VARIOGRAM MODEL PARAMETERS ON THE NEXT LINE
C0 = 0.01; C1 = 0.0025; C2 = 1; C3 = 0.28; C4 = 28;
vg_params = [C0 C1 C2 C3 C4];
%
% evaluate model variogram
x = [0:0.01:max(hc2)];
y = C0 + C1*((x.^2+C2^2).^0.5-C2) + C3*(1-exp(-(x/C4).^2));


% (3) plot fitting results
figure(1); plot(x,y,'k')
text(1,0.11,'Model curve:')
text(1,0.1,'gam = C0 + C1*((h^2+C2^2)^{0.5}-C2) + C3*(1-exp(-(h/C4)^2))')
text(1,0.09,['C0 = ' num2str(C0) '; C1 = ' num2str(C1) '; C2 = ' num2str(C2) '; C3 = ' num2str(C3) '; C4 = ' num2str(C4) ])
title('VARIOGRAM MANUAL-FITTING RESULTS (near origin)')
print -dtiff results/manualfit_model_variogram_1
%
figure(2); plot(x,y,'k');
text(7,0.7,'Model curve:')
text(7,0.63,'gam = C0 + C1*((h^2+C2^2)^{0.5}-C2) + C3*(1-exp(-(h/C4)^2))')
text(7,0.56,['C0 = ' num2str(C0) '; C1 = ' num2str(C1) '; C2 = ' num2str(C2) '; C3 = ' num2str(C3) '; C4 = ' num2str(C4) ])
title('VARIOGRAM MANUAL-FITTING RESULTS(for entire h-scale)')
print -dtiff results/manualfit_model_variogram_2


save results/model_variogram_parameters C0 C1 C2 C3 C4 vg_params

